<?php
/**
*
* @package phpBB Extension - DSGVO - Customize registration page
* @copyright (c) 2024 Chris1278
* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License v2
*
*/

namespace chris1278\regtemp\controller;

class acp_controller
{
	protected $ext_manager;
	protected $config;
	protected $language;
	protected $request;
	protected $template;
	protected $u_action;

	public function __construct(
		\phpbb\extension\manager $ext_manager,
		\phpbb\config\config $config,
		\phpbb\language\language $language,
		\phpbb\request\request $request,
		\phpbb\template\template $template
	)
	{
		$this->ext_manager					= $ext_manager;
		$this->md_manager 					= $this->ext_manager->create_extension_metadata_manager('chris1278/regtemp');
		$this->config						= $config;
		$this->language						= $language;
		$this->request						= $request;
		$this->template						= $template;
	}

	public function general_module()
	{
		$ext_display_ver 			= $this->md_manager->get_metadata('version');
		$ext_lang_min_ver 			= $this->md_manager->get_metadata()['extra']['lang-min-ver'];
		$ext_display_name 			= $this->md_manager->get_metadata('display-name');
		$lang_ver 					= ($this->language->lang('DSGVO_RC_LANG_EXT_VER') !== 'DSGVO_RC_LANG_EXT_VER') ? $this->language->lang('DSGVO_RC_LANG_EXT_VER') : '0.0.0';
		$notes 						= '';
		add_form_key('regtemp_settings');
		$errors = [];

		if ($this->request->is_set_post('submit'))
		{
			if (!check_form_key('regtemp_settings'))
			{
				$errors[] = $this->language->lang('FORM_INVALID');
			}

			if (empty($errors))
			{
				$this->config->set('dsgvo_rc_checkbox', $this->request->variable('dsgvo_rc_checkbox', 0));
				$this->config->set('dsgvo_rc_policy_extern', $this->request->variable('dsgvo_rc_policy_extern', 0));
				$this->config->set('dsgvo_rc_form', $this->request->variable('dsgvo_rc_form', 0));
				trigger_error($this->language->lang('ACP_DSGVO_RC_SETTING_SAVED')  . adm_back_link($this->u_action));
			}
		}

		$s_errors = !empty($errors);

		if (!phpbb_version_compare($lang_ver, $ext_lang_min_ver, '>='))
		{
			$this->add_note($notes, $this->language->lang('DSGVO_RC_MSG_LANGUAGEPACK_OUTDATED'));
		}

		$this->template->assign_vars([
			'DSGVO_RC_S_ERROR'						=> $s_errors,
			'DSGVO_RC_MSG'							=> $s_errors ? implode('<br>', $errors) : '',
			'DSGVO_RC_NOTES'						=> $notes,
			'DSGVO_RC_EXT_NAME'						=> $ext_display_name,
			'DSGVO_RC_EXT_VER'						=> $ext_display_ver,
			'DSGVO_RC_CHECKBOX'						=> $this->config['dsgvo_rc_checkbox'],
			'DSGVO_RC_POLICY_EXTERN'				=> $this->config['dsgvo_rc_policy_extern'],
			'DSGVO_RC_FORM'							=> $this->config['dsgvo_rc_form'],
			'U_ACTION'								=> $this->u_action,
		]);
	}

	private function add_note(string &$notes, $msg)
	{
		$notes .= (($notes != '') ? "\n" : "") . sprintf($this->language->lang('ACP_DSGVO_RC_NOTES'), $msg);
	}

	public function set_page_url($u_action)
	{
		$this->u_action = $u_action;
	}
}
